@@ -1,6 +1,9 @@
 use strict;
 use warnings;
 
+print "Gibberish stdout\n";
+print STDERR "Gibberish stderr\n";
+
 my $now = $ARGV[0];
 $ENV{"TESTONTAP_PREPROCESS_TEST_$now"} = 1;
 print "# BEGIN ENV\n";
@@ -11,3 +14,4 @@ print "# BEGIN ARGV\n";
 print "$_\n" foreach (@ARGV);
 print $now+1,"\n";
 print "# END ARGV\n";
+
